@@ -8,10 +8,11 @@ extern volatile BOOL gSigUser;
 
 /// ޥɤбʸ
 enum eCommandKind { 
+    kObject,
     kVar, kGlobal, kExport, 
     kAry, kAryAdd, kAryErase, 
     kHash, kHashAdd, kHashErase,  
-    kDef, kClass,
+    kDef, kInherit, kClass,
     kSubshell, kMSleep, kTrue, kFalse, kTest,
     kIndex, kRIndex, kLength, kLc, kUc,
     kChomp, kSubstr, kEval, kFg, kBg, 
@@ -350,13 +351,16 @@ void sStatments_save(sStatments* self, int fd);
 sStatments* sStatments_load(int fd);
 void sStatments_delete(sStatments* self);
 
-typedef struct {
+typedef struct _sFunction {
     string_obj* name;       // ޥ̾
     string_obj* arg_name;
+    //vector_obj* args;       // ե󥹤ΰ
     sStatments* statments; // ̿ɽ
+
+    struct _sFunction* parent;     // С饤ɤȤο
 } sFunction;
 
-sFunction* sFunction_new(char* name, MANAGED sStatments* statments, char* arg_name);
+sFunction* sFunction_new(char* name, MANAGED sStatments* statments, char* arg_name, sFunction* parent);
 sFunction* sFunction_new2(sFunction* func);
   
 void sFunction_delete(sFunction* self);
@@ -364,12 +368,13 @@ void sFunction_save(sFunction* self, int fd);
 sFunction* sFunction_load(int fd);
 void sFunction_view(sFunction* self);
 
-typedef struct {
+typedef struct _sClass {
     string_obj* name;      // 饹̾
     sStatments* statments; // ̿ɽ
+    struct _sClass* parent;        // С饤
 } sClass;
 
-sClass* sClass_new(char* name, sStatments* statments);
+sClass* sClass_new(char* name, sStatments* statments, sClass* parent);
 sClass* sClass_new2(sClass* klass);
   
 void sClass_save(sClass* self, int fd);
@@ -392,7 +397,7 @@ extern hash_obj* gObjects;
 ////////////////////////////////////////////////////////////
 /// from saphire_commands.c
 ////////////////////////////////////////////////////////////
-int statment_tree_internal_commands(sCommand* command, int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, int j, char* title, BOOL input, BOOL* return_, char* sname, int line, vector_obj* envs, sObject* object);
+int statment_tree_internal_commands(sCommand* command, int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, int j, char* title, BOOL input, BOOL* return_, char* sname, int line, vector_obj* envs, sObject* object, sFunction* running_fun, sClass* running_class);
 BOOL vcat_expand_env(string_obj* pipeout, char* env, vector_obj* numbers,char* sname, int line);
 
 ////////////////////////////////////////////////////////////
@@ -425,7 +430,7 @@ extern vector_obj* gStackTraceFName;
 extern vector_obj* gStackTraceLineNum;
     // åե졼εϿ
 
-int run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein, int pipeerr, BOOL* return_, vector_obj* parent_blocks, BOOL try_, vector_obj* envs, sObject* object);
+int run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein, int pipeerr, BOOL* return_, vector_obj* parent_blocks, BOOL try_, vector_obj* envs, sObject* object, sFunction* running_fun, sClass* running_class);
     // saphire_compile2ǥѥ뤷ѥ̤¹Ԥ롣
 
 int saphire_shell4(char* command, char* title, sWFd* pipeout, sRFd* pipein, int pipeerr, sObject* object);
