@@ -36,10 +36,10 @@ enum eKanjiCode gKanjiCode = kUtf8;
 
 
 char* gStatmentKindStrs[kCommand+1] = {
-    "var", "global", "export", 
+    "object", "var", "global", "export", 
     "ary", "ary_add", "ary_erase", 
     "hash", "hash_add", "hash_erase",
-    "def", "class",
+    "def", "inherit", "class",
     "subshell", "msleep", "true",  "false", "[",  
     "index", 
     "rindex", 
@@ -1952,11 +1952,12 @@ sStatments* sStatments_load(int fd)
 /////////////////////////////////////////////////////////
 // クラス
 /////////////////////////////////////////////////////////
-sClass* sClass_new(char* name, sStatments* statments)
+sClass* sClass_new(char* name, sStatments* statments, sClass* parent)
 {
     sClass* self = MALLOC(sizeof(sClass));
     self->name = STRING_NEW(name);
     self->statments = statments;
+    self->parent = parent;
 
     return self;
 }
@@ -1973,6 +1974,13 @@ sClass* sClass_new2(sClass* klass)
         self->statments = NULL;
     }
 
+    if(klass->parent) {
+        self->parent = sClass_new2(klass->parent);
+    }
+    else {
+        self->parent = NULL;
+    }
+
     return self;
 }
 
@@ -1989,6 +1997,23 @@ void sClass_save(sClass* self, int fd)
     }
 
     sStatments_save(self->statments, fd);
+
+    if(self->parent) {
+        char c = 1;
+        if(write(fd, &c, sizeof(char)) < 0) {
+            perror("write");
+            exit(1);
+        }
+        
+        sClass_save(self->parent, fd);
+    }
+    else {
+        char c = 0;
+        if(write(fd, &c, sizeof(char)) < 0) {
+            perror("write");
+            exit(1);
+        }
+    }
 }
 
 sClass* sClass_load(int fd)
@@ -2012,6 +2037,15 @@ sClass* sClass_load(int fd)
 
     self->statments = sStatments_load(fd);
 
+    char c;
+    if(read(fd, &c, sizeof(char)) < 0) {
+        perror("read");
+        exit(1);
+    }
+    if(c) { 
+        self->parent = sClass_load(fd);
+    }
+
     return self;
 }
 
@@ -2023,11 +2057,19 @@ void sClass_view(sClass* self)
 /////////////////////////////////////////////////////////
 // 関数
 /////////////////////////////////////////////////////////
-sFunction* sFunction_new(char* name, MANAGED sStatments* statments, char* arg_name)
+sFunction* sFunction_new(char* name, MANAGED sStatments* statments, char* arg_name, sFunction* parent)
 {
     sFunction* self = MALLOC(sizeof(sFunction));
     self->name = STRING_NEW(name);
     self->arg_name = STRING_NEW(arg_name);
+    self->parent = parent;
+/*
+    self->args = VECTOR_NEW(10);
+    int i;
+    for(i=0; i<vector_size(args); i++) {
+        vector_add(self->args, STRING_NEW(string_c_str(vector_item(args, i))));
+    }
+*/
     
     self->statments = statments;
 
@@ -2039,6 +2081,19 @@ sFunction* sFunction_new2(sFunction* func)
     sFunction* self = MALLOC(sizeof(sFunction));
     self->name = STRING_NEW(string_c_str(func->name));
     self->arg_name = STRING_NEW(string_c_str(func->arg_name));
+/*
+    self->args = VECTOR_NEW(10);
+    int i;
+    for(i=0; i<vector_size(func->args); i++) {
+        vector_add(self->args, STRING_NEW(string_c_str(vector_item(func->args, i))));
+    }
+*/
+    if(self->parent) {
+        self->parent = sFunction_new2(func->parent);
+    }
+    else {
+        self->parent = NULL;
+    }
     
     if(func->statments) {
         self->statments = sStatments_new2(func->statments);
@@ -2072,6 +2127,37 @@ void sFunction_save(sFunction* self, int fd)
     }
 
     sStatments_save(self->statments, fd);
+
+    if(self->parent) {
+        char c = 1;
+        write(fd, &c, sizeof(char));
+        sFunction_save(self->parent, fd);
+    }
+    else {
+        char c = 0;
+        write(fd, &c, sizeof(char));
+    }
+/*
+    n = vector_size(self->args);
+    if(write(fd, &n, sizeof(int)) < 0) {
+        perror("write");
+        exit(1);
+    }
+
+    int i;
+    for(i=0; i<vector_size(self->args); i++) {
+        string_obj* str = vector_item(self->args, i);
+        n = string_length(str);
+        if(write(fd, &n, sizeof(int)) < 0) {
+            perror("write");
+            exit(1);
+        }
+        if(write(fd, string_c_str(str), sizeof(char)*n) < 0) {
+            perror("write");
+            exit(1);
+        }
+    }
+*/
 }
 
 sFunction* sFunction_load(int fd)
@@ -2109,6 +2195,42 @@ sFunction* sFunction_load(int fd)
 
     self->statments = sStatments_load(fd);
 
+    char exists;
+    if(read(fd, &exists, sizeof(char)) < 0) {
+        perror("read");
+        exit(1);
+    }
+
+    if(exists) {
+        self->parent = sFunction_load(fd);
+    }
+/*
+    self->args = VECTOR_NEW(10);
+    
+    if(read(fd, &n, sizeof(int)) < 0) {
+        perror("read");
+        exit(1);
+    }
+
+    int i;
+    for(i=0; i<n; i++) {
+        int m;
+        if(read(fd, &m, sizeof(int)) < 0) {
+            perror("read");
+            exit(1);
+        }
+
+        char* buf = MALLOC(sizeof(char)*(m+1));
+        if(read(fd, buf, sizeof(char)*m) < 0) {
+            perror("read");
+            exit(1);
+        }
+        buf[m] = 0;
+
+        vector_add(self->args, STRING_NEW(buf));
+    }
+*/
+
     return self;
 }
 
@@ -2443,7 +2565,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "3.2.0", 1);
+    setenv("SAPHIRE_VERSION", "3.2.1", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
@@ -3429,6 +3551,8 @@ vector_obj* saphire_methods_names(sObject* object)
         it = hash_loop_next(it);
     }
 
+    vector_add(v, STRING_NEW("class"));
+
     return v;
 }
 
