@@ -929,6 +929,53 @@ static BOOL read_command_parse_def_statment(char** p, sCommand* command, sStatme
         string_push_back2(not_evaled, **p);
         (*p)++;
     }
+/*
+    /// 引数を取る ///
+    vector_obj* args = VECTOR_NEW(10);
+    string_obj* arg_name = STRING_NEW("");
+    if(**p == '(') {
+        string_push_back2(not_evaled, **p);
+        (*p)++;
+        while(1) {
+            skip_spaces(p, not_evaled);
+
+            string_obj* arg = STRING_NEW("");
+
+            while(**p >= 'a' && **p <= 'z' 
+                || **p >= 'A' && **p <= 'Z'
+                || **p == '_' 
+                || **p >= '0' && **p <= '9')
+            {
+                string_push_back2(not_evaled, **p);
+                string_push_back2(arg, **p);
+                (*p)++;
+            }
+
+            skip_spaces(p, not_evaled);
+
+            if(string_length(arg) > 0) {
+                vector_add(args, arg);
+            }
+
+            if(**p == ')') {
+                break;
+            }
+            else if(**p >= 'a' && **p <= 'z' 
+                || **p >= 'A' && **p <= 'Z'
+                || **p == '_' 
+                || **p >= '0' && **p <= '9')
+            {
+            }
+            else {
+                err_msg("invalid character in argument", sname, *sline);
+                return FALSE;
+            }
+        }
+
+        string_push_back2(not_evaled, **p);
+        (*p)++;
+    }
+*/
 
     while(**p) {
         if(**p == '\n') {
@@ -968,7 +1015,7 @@ static BOOL read_command_parse_def_statment(char** p, sCommand* command, sStatme
     command->mKind = kDef;
         // これが無いとmNotEvaledの場合（変数がある場合）
         // 正しくcommandが消されない
-    command->mExtra = sFunction_new(string_c_str(name), statments, string_c_str(arg_name));
+    command->mExtra = sFunction_new(string_c_str(name), statments, string_c_str(arg_name), NULL);
 
 
     return TRUE;
@@ -1028,7 +1075,7 @@ static BOOL read_command_parse_class_statment(char** p, sCommand* command, sStat
     command->mKind = kClass;
         // これが無いとmNotEvaledの場合（変数がある場合）
         // 正しくcommandが消されない
-    command->mExtra = sClass_new(string_c_str(name), statments);
+    command->mExtra = sClass_new(string_c_str(name), statments, NULL);
 
     return TRUE;
 }
@@ -2109,7 +2156,7 @@ int saphire_load_obj(char* fname, sWFd* pipeout, sRFd* pipein, int pipeerr, vect
     vector_obj* envs = VECTOR_NEW(10);
     int rcode = run(statments, fname
                 , pipeout, pipein, pipeerr
-                , &return_, parent_blocks, FALSE, envs, NULL);
+                , &return_, parent_blocks, FALSE, envs, NULL, NULL, NULL);
 
     /// 解放 ///
     close(fd);
