@@ -7,7 +7,7 @@
 //////////////////////////////////////////////////////////////////////
 // 初期化
 //////////////////////////////////////////////////////////////////////
-#ifdef MDEBUG
+#if defined(MDEBUG) && !defined(HAVE_GC_H) && !defined(HAVE_GC_GC_H)
 string_obj* string_new_debug(char* str, const char* fname, int line, const char* func_name)
 {
     string_obj* self;
