@@ -503,7 +503,7 @@ static BOOL statment_tree_external_command(sStatment* statment, vector_obj* argv
 }
 
 /// argvを作る
-static BOOL statment_tree_make_argv(sCommand* command, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, BOOL* return_, sRFd* nextin, sRFd* pipein, char* sname, int sline, vector_obj* envs, vector_obj* psubs, sObject* object)
+static BOOL statment_tree_make_argv(sCommand* command, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, BOOL* return_, sRFd* nextin, sRFd* pipein, char* sname, int sline, vector_obj* envs, vector_obj* psubs, sObject* object, sFunction* running_fun, sClass* running_class)
 {
     int ii;
     for(ii=0; ii<vector_size(command->mArgs); ii++) {
@@ -520,7 +520,7 @@ static BOOL statment_tree_make_argv(sCommand* command, vector_obj* argv, vector_
                 sWFd* pipeout = sWFd_new(-1);
                 int rcode = run(statments, "quick command expansion"
                     , pipeout, pipein, 2, return_, parent_blocks, FALSE
-                    , envs, object);
+                    , envs, object, running_fun, running_class);
 
                 if(rcode == -1) {
                     return FALSE;
@@ -539,7 +539,7 @@ static BOOL statment_tree_make_argv(sCommand* command, vector_obj* argv, vector_
                 sWFd* pipeout = sWFd_new(-1);
                 int rcode = run(statments, "quick command expansion"
                     , pipeout, pipein, 2, return_, parent_blocks, FALSE
-                    , envs, object);
+                    , envs, object, running_fun, running_class);
 
                 if(rcode == -1) {
                     return FALSE;
@@ -579,7 +579,7 @@ static BOOL statment_tree_make_argv(sCommand* command, vector_obj* argv, vector_
                 sWFd* pipeout = sWFd_new(-1);
                 int rcode = run(statments, "process substitution"
                     , pipeout, pipein, 2, return_, parent_blocks, FALSE
-                    , envs, object);
+                    , envs, object, running_fun, running_class);
 
                 if(rcode == -1) {
                     return FALSE;
@@ -689,7 +689,7 @@ static BOOL statment_tree_make_argv(sCommand* command, vector_obj* argv, vector_
 // 文を回す
 // TRUE 正常終了
 // FALSE エラー
-static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipeout, sRFd* pipein, int pipeerr, char* title, int* rcode, BOOL* return_, vector_obj* parent_blocks, char* sname, int sline, vector_obj* envs, vector_obj* psubs, sObject* object) 
+static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipeout, sRFd* pipein, int pipeerr, char* title, int* rcode, BOOL* return_, vector_obj* parent_blocks, char* sname, int sline, vector_obj* envs, vector_obj* psubs, sObject* object, sFunction* running_fun, sClass* running_class) 
 {
     sRFd* nextin;
     int nexterr = pipeerr;
@@ -752,7 +752,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
         // argvを作成 sArgから
         vector_obj* argv = VECTOR_NEW(30);
         vector_obj* blocks = VECTOR_NEW(30);
-        if(!statment_tree_make_argv(command, argv, blocks, parent_blocks, return_, nextin, pipein, sname, sline, envs, psubs, object)) {
+        if(!statment_tree_make_argv(command, argv, blocks, parent_blocks, return_, nextin, pipein, sname, sline, envs, psubs, object, running_fun, running_class)) {
             return FALSE;
         }
         if(*return_) {
@@ -768,6 +768,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
         sClass* klass;
         sInnerCommand* inner_fun;
         char* tmp = strstr(arg0, "->");
+        BOOL class_method = FALSE;
         if(tmp) {
             char* tmp2 = MALLOC(tmp - arg0 + 1);
             memcpy(tmp2, arg0, tmp-arg0);
@@ -796,13 +797,18 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
             char* tmp3 = MALLOC(arg0 + strlen(arg0) - tmp + 1);
             strcpy(tmp3, tmp);
 
-            method = hash_item(object2->mMethods, tmp3);
+            if(strcmp(tmp3, "class") == 0) {
+                class_method = TRUE;
+            }
+            else {
+                method = hash_item(object2->mMethods, tmp3);
 
-            if(method == NULL) {
-                char str[1024];
-                snprintf(str, 1024, "method(%s) is not found", tmp3);
-                err_msg(str, sname, sline);
-                return FALSE;
+                if(method == NULL) {
+                    char str[1024];
+                    snprintf(str, 1024, "method(%s) is not found", tmp3);
+                    err_msg(str, sname, sline);
+                    return FALSE;
+                }
             }
             fun = NULL;
             inner_fun = NULL;
@@ -858,7 +864,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
                 *rcode = run(klass->statments, title, nextout
                                 , nextin, nexterr
-                                , return_, parent_blocks, FALSE, envs, object2);
+                                , return_, parent_blocks, FALSE, envs, object2, NULL, klass);
                 *return_ = FALSE; // ユーザー関数が復帰したらreturn終わり
 
                 // スタックを埋める
@@ -894,6 +900,123 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
                 return FALSE;
             }
         }
+        /// 継承 ///
+        else if(class_method) {
+            if(vector_size(argv) >= 2) {
+                char* klassname = string_c_str(vector_item(argv, 1));
+
+                /// スタックフレームの記録を付ける
+                vector_add(gStackTraceFName, STRING_NEW(sname));
+                vector_add(gStackTraceLineNum, (void*)sline);
+
+                // スタックを掘る
+                vector_add(gStackFrame, HASH_NEW(30));
+
+                if(object) {
+                    klass = hash_item(object->mClasses, klassname);
+                    if(klass == NULL) {
+                        sObject* parent = object->mParent;
+                        while(parent) {
+                            klass = hash_item(parent->mClasses, klassname);
+                            if(klass) break;
+                            parent = parent->mParent;
+                        }
+                    }
+                    if(klass == NULL) {
+                        klass = hash_item(gClasses, klassname);
+                    }
+                }
+                else {
+                    klass = hash_item(gClasses, klassname);
+                }
+
+                if(klass == NULL) {
+                    err_msg("class name is not found", sname, sline);
+                    return FALSE;
+                }
+                
+                *rcode = run(klass->statments, title, nextout
+                                , nextin, nexterr
+                                , return_, parent_blocks, FALSE, envs, object2, NULL, klass);
+                *return_ = FALSE; // ユーザー関数が復帰したらreturn終わり
+
+                // スタックを埋める
+                vector_pop_back(gStackFrame);
+
+                /// スタックフレームの記録を消す
+                string_obj* sname_strace = vector_pop_back(gStackTraceFName);
+                int line_strace = (int)vector_pop_back(gStackTraceLineNum);
+
+                /// 終了コード ///
+                if(statment->mRCodeReverse) {
+                    if(*rcode == 0) 
+                        *rcode = 1;
+                    else
+                        *rcode = 0;
+                }
+
+                char buf2[256];
+                snprintf(buf2, 256, "%d", *rcode);
+                saphire_set_local_var("RCODE", buf2);
+
+                if(*rcode < 0) {
+                    string_push_back(gErrMsg, string_c_str(sname_strace));
+                    char tmp[1024];
+                    snprintf(tmp, 1024, ":%d\n", line_strace);
+                    string_push_back(gErrMsg, tmp);
+
+                    return FALSE;
+                }
+            }
+            else if(vector_size(blocks) == 1) {
+                /// スタックフレームの記録を付ける
+                vector_add(gStackTraceFName, STRING_NEW(sname));
+                vector_add(gStackTraceLineNum, (void*)sline);
+
+                // スタックを掘る
+                vector_add(gStackFrame, HASH_NEW(30));
+
+                sBlock* block = vector_item(blocks, 0);
+                sStatments* statments = block->mStatments;
+                
+                *rcode = run(statments, title, nextout
+                                , nextin, nexterr
+                                , return_, parent_blocks, FALSE, envs, object2, NULL, NULL);
+                *return_ = FALSE; // ユーザー関数が復帰したらreturn終わり
+
+                // スタックを埋める
+                vector_pop_back(gStackFrame);
+
+                /// スタックフレームの記録を消す
+                string_obj* sname_strace = vector_pop_back(gStackTraceFName);
+                int line_strace = (int)vector_pop_back(gStackTraceLineNum);
+
+                /// 終了コード ///
+                if(statment->mRCodeReverse) {
+                    if(*rcode == 0) 
+                        *rcode = 1;
+                    else
+                        *rcode = 0;
+                }
+
+                char buf2[256];
+                snprintf(buf2, 256, "%d", *rcode);
+                saphire_set_local_var("RCODE", buf2);
+
+                if(*rcode < 0) {
+                    string_push_back(gErrMsg, string_c_str(sname_strace));
+                    char tmp[1024];
+                    snprintf(tmp, 1024, ":%d\n", line_strace);
+                    string_push_back(gErrMsg, tmp);
+
+                    return FALSE;
+                }
+            }
+            else {
+                err_msg("reuire class name or a block", sname, sline);
+                return FALSE;
+            }
+        }
         /// メソッド ///
         else if(method) {
             if(!statment_tree_redirect(command, &nextin, &nextout
@@ -907,7 +1030,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
             vector_obj* fun_argv;
             if(strcmp(string_c_str(method->arg_name), "") == 0) {
                 /// 前の引数を保存 ///
-                fun_argv_before = hash_item(gArrays, "ARGV");
+                fun_argv_before = hash_item(object2->mArrays, "ARGV");
 
                 /// 引数を渡す ///
                 int k;
@@ -917,14 +1040,14 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
                     vector_add(fun_argv, STRING_NEW(value));
                 }
                 
-                hash_put(gArrays, "ARGV", fun_argv);
+                hash_put(object2->mArrays, "ARGV", fun_argv);
 
                 vector_add(gStackFrame, HASH_NEW(30));
             }
             /// 引数名が指定されていなければスタックフレームは増やさない
             else {
                 /// 前の引数を保存 ///
-                fun_argv_before = hash_item(gArrays
+                fun_argv_before = hash_item(object2->mArrays
                                         , string_c_str(method->arg_name));
 
                 /// 引数を渡す ///
@@ -935,7 +1058,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
                     vector_add(fun_argv, STRING_NEW(value));
                 }
                 
-                hash_put(gArrays, string_c_str(method->arg_name), fun_argv);
+                hash_put(object2->mArrays, string_c_str(method->arg_name), fun_argv);
             }
 
             /// スタックフレームの記録を付ける
@@ -944,7 +1067,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
             /// 実行 ///
             *rcode = run(method->statments, title
-                , nextout, nextin, nexterr, return_, blocks, FALSE, envs, object2);
+                , nextout, nextin, nexterr, return_, blocks, FALSE, envs, object2, method, running_class);
             *return_ = FALSE; // ユーザー関数が復帰したらreturn終わり
 
             /// スタックフレームの記録を消す
@@ -957,20 +1080,20 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
                 hash_obj* stack = vector_pop_back(gStackFrame);
 
                 /// 引数を消す ///
-                hash_erase(gArrays, "ARGV");
+                hash_erase(object2->mArrays, "ARGV");
 
                 /// 前の引数を元に戻す ///
                 if(fun_argv_before) {
-                    hash_put(gArrays, "ARGV", fun_argv_before);
+                    hash_put(object2->mArrays, "ARGV", fun_argv_before);
                 }
             }
             else {
                 /// 引数を消す ///
-                hash_erase(gArrays, string_c_str(method->arg_name));
+                hash_erase(object2->mArrays, string_c_str(method->arg_name));
 
                 /// 前の引数を元に戻す ///
                 if(fun_argv_before) {
-                    hash_put(gArrays, string_c_str(method->arg_name)
+                    hash_put(object2->mArrays, string_c_str(method->arg_name)
                                 , fun_argv_before);
                 }
             }
@@ -1047,7 +1170,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
 
             /// 実行 ///
             *rcode = run(fun->statments, title
-                , nextout, nextin, nexterr, return_, blocks, FALSE, envs, object);
+                , nextout, nextin, nexterr, return_, blocks, FALSE, envs, object, fun, running_class);
             *return_ = FALSE; // ユーザー関数が復帰したらreturn終わり
 
             /// スタックフレームの記録を消す
@@ -1162,7 +1285,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
             }
 
             BOOL r = statment_tree_internal_commands(command, rcode
-                , argv, blocks, parent_blocks, nextout, nextin, nexterr, j, title, !first_program || exist_globalin || exist_stdinpipe,return_, sname, sline, envs, object);
+                , argv, blocks, parent_blocks, nextout, nextin, nexterr, j, title, !first_program || exist_globalin || exist_stdinpipe,return_, sname, sline, envs, object, running_fun, running_class);
 
             /// 終了コード ///
             if(statment->mRCodeReverse) {
@@ -1395,7 +1518,7 @@ void run_wait_cprogs(sStatment* statment, int* rcode, sWFd* pipeout, int last_pr
 }
 
 // 複文を実行したい関数。本体。
-int run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein, int pipeerr, BOOL* return_, vector_obj* parent_blocks, BOOL try_, vector_obj* envs, sObject* object)
+int run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein, int pipeerr, BOOL* return_, vector_obj* parent_blocks, BOOL try_, vector_obj* envs, sObject* object, sFunction* running_fun, sClass* running_class)
 {
     int rcode = 0;
 
@@ -1415,7 +1538,7 @@ int run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein, int pip
                 if(parse(string_c_str(cmdline), sname, &sline, estatments)) 
                 {
                     rcode = run(estatments, title, pipeout, pipein
-                        , pipeerr, return_, parent_blocks, FALSE, envs, object);
+                        , pipeerr, return_, parent_blocks, FALSE, envs, object, running_fun, running_class);
                     if(*return_) {
                         return 0;
                     }
@@ -1443,7 +1566,7 @@ int run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein, int pip
                           , pipeout, pipein, pipeerr
                           , title, &rcode
                           , return_, parent_blocks , sname, sline
-                          , envs, psubs, object);
+                          , envs, psubs, object, running_fun, running_class);
 
             /// プロセス回収 ///
             if(last_program_pid != -1) {
@@ -1469,7 +1592,7 @@ int run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein, int pip
                 sRFd* nextin2 = sRFd_new(f);
                 int rcode = run(psub->mStatments, "process substitution2"
                     , pipeout, nextin2, 2, return_, parent_blocks, FALSE
-                    , envs, object);
+                    , envs, object, running_fun, running_class);
 
                 (void)close(f);
 
@@ -1599,7 +1722,7 @@ int saphire_shell(char* command, char* fname, sWFd* pipeout, sRFd* pipein, int p
         vector_obj* envs = VECTOR_NEW(10);
         int rcode = run(statments, string_c_str(fname2)
                     , pipeout, pipein, pipeerr
-                    , &return_, NULL, FALSE, envs, NULL);
+                    , &return_, NULL, FALSE, envs, NULL, NULL, NULL);
 
         /// 解放 ///
         return rcode;
@@ -1656,7 +1779,7 @@ int saphire_shell4(char* command, char* fname, sWFd* pipeout, sRFd* pipein, int
         vector_obj* envs = VECTOR_NEW(10);
         int rcode = run(statments, string_c_str(fname2)
                     , pipeout, pipein, pipeerr
-                    , &return_, NULL, FALSE, envs, object);
+                    , &return_, NULL, FALSE, envs, object, NULL, NULL);
 
         /// 解放 ///
         return rcode;
@@ -1894,7 +2017,7 @@ int saphire_run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein,
     int return_ = FALSE;
     vector_obj* envs = VECTOR_NEW(10);
     int r = run(statments, title, pipeout, pipein, pipeerr
-            , &return_, NULL, FALSE, envs, NULL);
+            , &return_, NULL, FALSE, envs, NULL, NULL, NULL);
 
     return r;
 }
